The kwdagger Module
===================



|Pypi| |PypiDownloads| |ReadTheDocs| |GitlabCIPipeline| |GitlabCICoverage|



+-----------------+-------------------------------------------+
| Read the Docs   | http://kwdagger.readthedocs.io/en/latest/ |
+-----------------+-------------------------------------------+
| Gitlab (main)   |                                           |
+-----------------+-------------------------------------------+
| Github (mirror) | https://github.com/Kitware/kwdagger       |
+-----------------+-------------------------------------------+
| Pypi            | https://pypi.org/project/kwdagger         |
+-----------------+-------------------------------------------+



.. |Pypi| image:: https://img.shields.io/pypi/v/kwdagger.svg
    :target: https://pypi.python.org/pypi/kwdagger

.. |PypiDownloads| image:: https://img.shields.io/pypi/dm/kwdagger.svg
    :target: https://pypistats.org/packages/kwdagger

.. |ReadTheDocs| image:: https://readthedocs.org/projects/kwdagger/badge/?version=latest
    :target: http://kwdagger.readthedocs.io/en/latest/

.. |GitlabCIPipeline| image:: https://gitlab.kitware.com/computer-vision/kwdagger/badges/main/pipeline.svg
    :target: https://gitlab.kitware.com/computer-vision/kwdagger/-/jobs

.. |GitlabCICoverage| image:: https://gitlab.kitware.com/computer-vision/kwdagger/badges/main/coverage.svg
    :target: https://gitlab.kitware.com/computer-vision/kwdagger/commits/main